<p align="center">
  <img width="300" src="https://raw.githubusercontent.com/ismailuddin/mongo-dash/main/artwork/mongo-dash-logo.png">
</p>

# Mongo Dash
> A dashboard solution for MongoDB databases.

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

![Screenshot](https://raw.githubusercontent.com/ismailuddin/mongo-dash/main/artwork/screenshot.png)

Visit the [website](https://mongo-dash.vercel.app/) for more details.

## Requirements
- Python 3.6 or newer

## 🛠 Installation
To install the package, you can either clone the repository and run the following command:

```shell
$   pip install .
```

Or you can install the package from PyPI using the command:

```shell
$   pip install mongo_dash
```


## 🚀 Usage
For a quick setup, visit the [Getting started](https://mongo-dash-docs.vercel.app/docs/getting-started/first-dashboard) page on the documentation.

## 📚 Documentation
View the [documenation](https://mongo-dash-docs.vercel.app/docs).
